<!-- 日常养护 --- 逾期工单 -->
<template>
    <div class="container">
        <div class="header">
            <div class="title">
                <i class="title-icon"></i>
                <span class="title-text">逾期工单统计</span>
            </div>
            <i class="back-icon" @click="handleReset"></i>
        </div>
        <div class="search">
            <!-- <el-date-picker
                v-model="date"
                type="daterange"
                range-separator="至"
                start-placeholder="开始日期"
                end-placeholder="结束日期"
                value-format="yyyy-MM-dd"
                @change="changeYear"
                style="margin-right: 10px"
            >
            </el-date-picker> -->
            <el-date-picker
                v-model="startTime"
                type="date"
                placeholder="请选择开始日期"
                value-format="yyyy-MM-dd"
            >
            </el-date-picker>
            <el-date-picker
                v-model="endTime"
                type="date"
                placeholder="请选择结束日期"
                value-format="yyyy-MM-dd"
            >
            </el-date-picker>
            <el-button
                size="small"
                @click="handleSearch"
                type="primary"
                :loading="loading"
                >查询</el-button
            >
            <el-button size="small" @click="reset" type="plain"> 重置 </el-button>
        </div>
        <div class="table">
            <el-table
                :data="tableData"
                stripe
                v-loading="loading"
                @row-click="hanldeRowClick"
                @cell-click="handleCellClick"
                header-cell-class-name="custom-header-cell"
                cell-class-name="custom-cell"
            >
                <el-table-column label="序号" type="index" width="70" align="center">
                </el-table-column>
                <el-table-column align="center" prop="name" label="名称">
                    <template v-slot="{row}">
                        <i class="el-icon-arrow-down" style="margin-right: 10px"></i>
                        {{ row.name }}
                    </template>
                </el-table-column>
                <el-table-column align="center" prop="overdueCount" label="逾期数量">
                    <template v-slot="{row}">
                        {{ utils.thousandBit(row.overdueCount) }}
                    </template>
                </el-table-column>
                <el-table-column align="center" prop="allCount" label="总数">
                    <template v-slot="{row}">
                        {{ utils.thousandBit(row.allCount) }}
                    </template>
                </el-table-column>
            </el-table>
            <div class="table-total">
                <span>{{ tableData.length + 1 }}</span>
                <span>总数</span>
                <span>{{ total.overdueCount || 0 }}</span>
                <span>{{ total.allCount || 0 }}</span>
            </div>
        </div>
    </div>
</template>

<script>
import utils from '@/utils' // thousandBit格式化千分位
const BigNumber = require('bignumber.js')
export default {
    name: 'DailyMaintenance',
    data() {
        return {
            tableData: [],
            data: [],
            startTime: this.diffMonth(6).split(' ')[0],
            endTime: utils.formatDate(new Date()).split(' ')[0],
            loading: false,
            cstatus: '',
            date: '',
            total: {},
            utils: utils,
            path: '1419863231459102720,',
        }
    },
    created() {
        let endDate = utils.formatDate(new Date()).split(' ')[0]
        // 获取当前时间6个月前的时间
        let startDate = this.diffMonth(6).split(' ')[0]
        this.date = [startDate, endDate]
        this.loadData()
    },
    watch: {
        tableData(newVal) {
            this.total.allCount = this.calculation('allCount', newVal)
            this.total.overdueCount = this.calculation('overdueCount', newVal)
        },
    },
    methods: {
        reset() {
            this.date = ''
            this.startTime = ''
            this.endTime = ''
            this.loadData()
        },
        /**
         * @description: 获取当前日期n个月前的日期
         * @param {String} n 几个月（为负数则表示前面的日期）
         * @return: 日期
         */
        diffMonth(n) {
            var dt = new Date()
            dt.setMonth(dt.getMonth() - Number(n))
            return dt.toLocaleString().replace(/\//g, '-')
        },
        calculation(key, arr) {
            let total = 0
            if (!key || arr.length === 0) return total
            arr.forEach((item) => {
                total += parseInt(item[key])
            })
            if (total === 0) return 0
            return utils.thousandBit(total)
        },
        changeYear(val) {
            if (!val) {
                return this.loadData()
            }
            this.loading = true
            this.$http
                .post(
                    '${yhxt}/workOrderInformation/v1/getWorkTimeOutCountVo' +
                        `?startDate=${this.startTime}&endDate=${this.endTime}`
                )
                .then((res) => {
                    this.tableData = (res && res.status == 200 && res.data) || []
                    this.data = []
                    this.data.push(this.tableData)
                    this.loading = false
                })
        },
        handleReset() {
            let length = this.data.length - 1
            if (length === 0) return
            this.tableData = this.data[this.data.length - 2]
            this.data.splice(length, 1)
        },
        hanldeRowClick(row) {
            console.log(this.date, 'this.date')
            if (row.chirldren.length == 0 && row.roadId) {
                this.path += row.roadId
                return this.$router.push({
                    name: 'overdueWorkOrdersChildren',
                    params: {
                        value: row,
                        cstatus: this.cstatus,
                        date: this.date,
                        startTime: this.startTime,
                        endTime: this.endTime,
                        path: this.path,
                    },
                })
            } else {
                this.path += row.id + ','
            }
            this.tableData = row.chirldren
            this.data.push(row.chirldren)
        },
        handleCellClick(row, column) {
            this.cstatus = column.columnKey
        },
        loadData() {
            this.loading = true
            let str = ''
            if (this.startTime || this.endTime) {
                str = `?startDate=${this.startTime}&endDate=${this.endTime}`
            }

            this.$http
                .post('${yhxt}/workOrderInformation/v1/getWorkTimeOutCountVo' + str)
                .then((res) => {
                    this.tableData = (res && res.status == 200 && res.data) || []
                    this.data = []
                    this.data.push(this.tableData)
                    this.loading = false
                })
                .catch(() => {
                    this.loading = false
                })
        },
        //查询
        handleSearch() {
            this.date = [this.startTime, this.endTime]
            this.loadData()
        },
    },
}
</script>

<style lang="scss" scoped>
/deep/ .el-date-editor {
    background-color: #103c5d;
    border: none;
}
/deep/ .el-range-separator {
    color: #fff;
}
/deep/ .el-table th.is-leaf {
    background-color: transparent !important;
}
/deep/ .el-table__row {
    background-color: #0b426e !important;
}
/deep/ .el-table__row--striped {
    background-color: #124873 !important;
}
/deep/ .el-table__header-wrapper {
    border-top-left-radius: 10px;
    border-top-right-radius: 10px;
}
/deep/ .el-table__body-wrapper {
    border-bottom-left-radius: 10px;
    border-bottom-right-radius: 10px;
}
/deep/ .el-table {
    background-color: transparent;
}
.container {
    padding: 30px;

    .header {
        height: 59px;
        width: 100%;
        display: flex;
        justify-content: space-between;
        border-bottom: 1px solid #4d7faf;
        .title {
            display: flex;
            height: 34px;
            align-items: center;
            .title-icon {
                display: block;
                width: 28px;
                height: 28px;
                background-image: url('../../assets/img/icon-标题@2x.png');
                background-size: 100% 100%;
            }
            .title-text {
                margin-left: 5px;
                height: 34px;
                font-size: 26px;
                font-family: Microsoft YaHei, Microsoft YaHei;
                font-weight: 700;
                line-height: 34px;
                color: transparent;
                -webkit-background-clip: text;
                background-image: linear-gradient(180deg, #e5f2ff 24%, #1f5c99 100%);
            }
        }
        .back-icon {
            margin-right: 10px;
            cursor: pointer;
            display: block;
            width: 40px;
            height: 40px;
            background-size: 100% 100%;
            background-image: url(../../assets//img/icon-返回@2x.png);
        }
    }
    .search {
        margin-top: 32px;
    }

    .table {
        margin-top: 12px;
        width: 100%;
        /deep/ .custom-header-cell {
            background-color: #145080 !important;
            padding: 15px 0;
            .cell {
                font-size: 18px;
                font-family: Microsoft YaHei, Microsoft YaHei;
                font-weight: 700;
                color: #e7edf0;
            }
        }
        /deep/ .custom-cell {
            padding: 15px 0;
            cursor: pointer;
            .cell,
            div {
                font-size: 16px;
                font-family: Microsoft YaHei, Microsoft YaHei;
                font-weight: 400;
                color: #e5f2ff;
            }
        }
        .table-total {
            display: flex;
            justify-content: center;
            align-items: center;
            height: 64px;
            background-color: #145080;
            border-radius: 10px;
            margin-top: 8px;
            span {
                font-size: 18px;
                font-family: Microsoft YaHei, Microsoft YaHei;
                font-weight: 700;
                color: #e7edf0;
                text-align: center;
                &:nth-child(1) {
                    width: 70px;
                }
                &:not(:nth-child(1)) {
                    flex: 1;
                }
            }
        }
    }
}
</style>
